@@ -1,5 +1,5 @@
-// Copyright (C) 2010, 2011 EPITA Research and Development Laboratory
-// (LRDE)
+// Copyright (C) 2010, 2011, 2013 EPITA Research and Development
+// Laboratory (LRDE)
 //
 // This file is part of Olena.
 //
@@ -18,18 +18,15 @@
 #include <QtGui>
 #include <iostream>
 
-# ifdef HAVE_TESSERACT_2
-#include <clocale>
-# endif // ! HAVE_TESSERACT_2
-
 #undef MLN_WO_GLOBAL_VARS
 #include "viewer.hh"
 #include <mln/labeling/colorize.hh>
 #include <mln/math/pi.hh>
 #include <mln/io/magick/load.hh>
-#include <scribo/make/debug_filename.hh>
 #include <mln/debug/filename.hh>
 #include <mln/literal/colors.hh>
+#include <scribo/make/debug_filename.hh>
+#include <scribo/binarization/sauvola_ms.hh>
 
 int main(int argc, char** argv)
 {
@@ -42,22 +39,10 @@ int main(int argc, char** argv)
     return 0;
   }
 
-  Magick::InitializeMagick(*argv);
-
   Viewer* viewer = Viewer::Instance(argc, argv);
 
   if (!viewer)
     return -1;
 
-
-# ifdef HAVE_TESSERACT_2
-  // Tesseract 2.x is known to have issues while reading training data
-  // depending on the current locales in use. Training data files use
-  // float data and the decimal separator can be either '.' or ','
-  // causing errors.
-  // Setting locale to "C" fix that issue.
-  setlocale(LC_ALL, "C");
-# endif // ! HAVE_TESSERACT_2
-
   return viewer->exec();
 }
