@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 
-# Copyright (C) 2008, 2009 EPITA Research and Development Laboratory (LRDE)
+# Copyright (C) 2008, 2009, 2010, 2012, 2013 EPITA Research and Development
+# Laboratory (LRDE)
 #
 # This file is part of Olena.
 #
@@ -19,10 +20,10 @@
 # \file swilena.py
 # \brief The whole Swilena suite.
 
-import ltihooks
-
 import config
 
+from complex2 import *
+
 from box2d import *
 from point2d import *
 from dpoint2d import *
@@ -30,7 +31,11 @@ from neighb2d import *
 from window2d import *
 
 from int_u8 import *
-from int_u32 import *
+from int_u24 import *
+from rgb8 import *
 
 import image2d_int
 import image2d_int_u8
+import image2d_rgb8
+
+import image2d_point2d
